/*
 * This file is part of OpenTTD.
 * OpenTTD is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, version 2.
 * OpenTTD is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details. You should have received a copy of the GNU General Public License along with OpenTTD. If not, see <http://www.gnu.org/licenses/>.
 */

/** @file station_area_func.h Base functions for StationArea. */





#ifndef STATION_AREA_FUNC_H
#define STATION_AREA_FUNC_H





#include "station_area.h"
#include "station_type.h"
#include "base_station_base.h"

#include "../command_type.h"
#include "../tilearea_type.h"





bool          IsStationAreaEmpty   (const StationArea *station_area);
void          EmptyStationArea     (StationArea *station_area);

bool          PtInExtendedRect     (StationArea *station_area, int x, int y, int distance = 0);

CommandCost   BeforeAddTile        (StationArea *station_area, TileIndex tile, StationAreaMode station_area_mode);
CommandCost   BeforeAddRect        (StationArea *station_area, TileIndex tile, int w, int h, StationAreaMode staton_area_mode);

bool          AfterRemoveTile      (StationArea *station_area, BaseStation *station, TileIndex tile_index);
bool          AfterRemoveRect      (StationArea *station_area, BaseStation *station, TileArea tile_area);

bool          ScanForStationTiles  (StationArea *station_area, StationID station_id,
								   int left_a, int top_a, int right_a, int bottom_a);
StationArea&  CopyStationArea      (StationArea *dest_area, Rect *src_rect);






#endif /* STATION_AREA_FUNC_H */
