/*
 * This file is part of OpenTTD.
 * OpenTTD is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, version 2.
 * OpenTTD is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details. You should have received a copy of the GNU General Public License along with OpenTTD. If not, see <http://www.gnu.org/licenses/>.
 */

/** @file order_func_local.h Functions related to orders. */



#ifndef ORDER_FUNC_LOCAL_H
#define ORDER_FUNC_LOCAL_H



#include "order_type.h"

#include "../command_type.h"
#include "../vehicle/vehicle_type.h"



int   InsertStationOrder              (Vehicle *v, Order *new_order, CommandCost *ret);
int   InsertDepotOrder                (Vehicle *v, Order *new_order, CommandCost *ret);
int   InsertWaypointOrder             (Vehicle *v, Order *new_order, CommandCost *ret);
int   InsertConditionalOrder          (Vehicle *v, Order *new_order);
void  InsertOrderAt                   (Vehicle *vehicle, Order *new_order, int index);
void  MoveOrder                       (OrderList *order_list, int from, int to);
void  DeleteOrder                     (Vehicle *v, VehicleOrderID sel_ord);
void  DeleteOrderAt                   (OrderList *order_list, Vehicle *vehicle, int index);
void  FreeChain                       (OrderList *order_list, bool keep_orderlist = false);

bool  CanLoadOrUnload                 (const Order *order);
void  CancelLoadingDueToDeletedOrder  (Vehicle *vehicle);
void  DrawOrderString                 (const Vehicle *v, const Order *order, int order_index, int y, bool selected,
									   bool timetable, int left, int middle, int right);
void  RecalculateTimetableDuration    (OrderList *order_list);

#ifdef WITH_ASSERT
void  OrderListCheckSanity            (OrderList *order_list);
#endif




#endif /* ORDER_FUNC_LOCAL_H */
