/*
 * This file is part of OpenTTD.
 * OpenTTD is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, version 2.
 * OpenTTD is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details. You should have received a copy of the GNU General Public License along with OpenTTD. If not, see <http://www.gnu.org/licenses/>.
 */

/** @file order_base.h Base class for orders. */



#ifndef ORDERLIST_H
#define ORDERLIST_H



#include "order_type.h"

#include "../vehicle/vehicle_type.h"
#include "../date_type.h"



/**
 * Shared order list linking together the linked list of orders and the list
 *  of vehicles sharing this order list.
 */

struct OrderList : OrderListPool::PoolItem<&_orderlist_pool> {

	Order     *first;               ///< First order of the order list.
	byte       num_orders;          ///< How many orders there are in the list.
	uint       num_vehicles;        ///< NOSAVE: Number of vehicles that share this order list.
	Vehicle   *first_shared;        ///< NOSAVE: pointer to the first vehicle in the shared order chain.

	TimeTick   timetable_interval;  ///< Interval between beginning the order list.
	TimeTick   timetable_duration;  ///< NOSAVE: Total timetabled duration of the order list.



	/** Default constructor producing an invalid order list. */
	OrderList (byte num_orders = 0)
		: first (nullptr), num_orders (num_orders), num_vehicles (0), first_shared (nullptr),
		  timetable_interval (0), timetable_duration (0)
	{ }



	/** Destructor. Invalidates OrderList for re-usage by the pool. */
	~OrderList() {}
};



#endif /* ORDERLIST_H */
