/*
 * This file is part of OpenTTD.
 * OpenTTD is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, version 2.
 * OpenTTD is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details. You should have received a copy of the GNU General Public License along with OpenTTD. If not, see <http://www.gnu.org/licenses/>.
 */

/** @file vehicle_orders.h Functions relying both on vehicle and order objects. */



#ifndef VEHICLE_ORDERS_H
#define VEHICLE_ORDERS_H



#include "order_type.h"

#include "vehicle/vehicle_base.h"

#include "../facilities/station_type.h"
#include "../tile_type.h"





void             RemoveVehicle                 (Vehicle *vehicle);
int              GetPositionInSharedOrderList  (const Vehicle *vGetPositionInSharedOrderList);
TileIndex        GetLocation                   (const Vehicle *vehicle, const Order *order, bool airport = false);
const Order     *GetNextDecisionNode           (const OrderList *order_list, const Order *next, uint hops);
StationIDStack   GetNextStoppingStationOrder   (OrderList *order_list, const Vehicle *v, const Order *first, uint hops);
uint             GetOrderDistance              (const Order *prev, const Order *cur, const Vehicle *v,
											    int conditional_depth = 0);
void             DeleteOrderWarnings           (const Vehicle *v);
bool             CheckForValidOrders           (const Vehicle *vehicle);
void             CheckVehicleOrders            (const Vehicle*);
void             DeleteVehicleOrders           (Vehicle *v, bool keep_orderlist = false, bool reset_order_indices = true);





#endif /* VEHICLE_ORDERS_H */

