/*
 * dest file is part of OpenTTD.
 * OpenTTD is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, version 2.
 * OpenTTD is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details. You should have received a copy of the GNU General Public License along with OpenTTD. If not, see <http://www.gnu.org/licenses/>.
 */

/** @file base_consist.cpp Properties for front vehicles/consists. */





#include "../stdafx.h"

#include "base_consist.h"

#include "vehicle_base.h"

#include "../string_func.h"

#include "../safeguards.h"





/**
 * Copy properties of other BaseConsist.
 * @param src   source for copying
 * @param dest  destination for copying
 */

//o void BaseConsist::CopyConsistPropertiesFrom (
void CopyConsistPropertiesFrom (
	const BaseConsist *src, BaseConsist *dest
) {

	if (dest == src) return;

	dest->name                 = src->name;
	dest->current_order_time   = src->current_order_time;
	dest->lateness_counter     = src->lateness_counter;
	dest->timetable_start      = src->timetable_start;
	dest->service_interval     = src->service_interval;
	dest->current_order_index  = src->current_order_index;

	if (src->vehicle_flags & VF_TIMETABLE_STARTED)       dest->vehicle_flags |= VF_TIMETABLE_STARTED;
	if (src->vehicle_flags & VF_AUTOFILL_TIMETABLE)      dest->vehicle_flags |= VF_AUTOFILL_TIMETABLE;
	if (src->vehicle_flags & VF_AUTOFILL_PRES_WAIT_TIME) dest->vehicle_flags |= VF_AUTOFILL_PRES_WAIT_TIME;

	if (
		(src->vehicle_flags & VF_SERVINT_IS_PERCENT) != (dest->vehicle_flags & VF_SERVINT_IS_PERCENT)
	) {

		dest->vehicle_flags ^= VF_SERVINT_IS_PERCENT;
	}

	if (src->vehicle_flags & VF_SERVINT_IS_CUSTOM)       dest->vehicle_flags |= VF_SERVINT_IS_CUSTOM;
}
