/*
 * This file is part of OpenTTD.
 * OpenTTD is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, version 2.
 * OpenTTD is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details. You should have received a copy of the GNU General Public License along with OpenTTD. If not, see <http://www.gnu.org/licenses/>.
 */

/** @file  vehicle_base.h Base class for all vehicles. */





#ifndef ORDER_ITERATOR_H
#define ORDER_ITERATOR_H





#include "../orders/order.h"
#include "../orders/orderlist.h"





/**
 * Iterator to iterate orders
 * Supports deletion of current order
 */

struct OrderIterator {

	typedef Order value_type;
	typedef Order* pointer;
	typedef Order& reference;
	typedef size_t difference_type;
	typedef std::forward_iterator_tag iterator_category;

	explicit OrderIterator(OrderList *list) : list(list), prev(nullptr)
	{
		this->order = (this->list == nullptr) ? nullptr : this->list->first;
	}

	bool operator==(const OrderIterator &other) const { return this->order == other.order; }
	bool operator!=(const OrderIterator &other) const { return !(*this == other); }
	Order * operator*() const { return this->order; }

	OrderIterator & operator++()
	{
		this->prev = (this->prev == nullptr) ? this->list->first : this->prev->next;
		this->order = (this->prev == nullptr) ? nullptr : this->prev->next;
		return *this;
	}

private:

	OrderList *list;
	Order *order;
	Order *prev;
};





/**
 * Iterable ensemble of orders
 */

struct IterateWrapper {

	OrderList *list;

	IterateWrapper(OrderList *list = nullptr) : list(list) {}
	OrderIterator begin() { return OrderIterator(this->list); }
	OrderIterator end() { return OrderIterator(nullptr); }
	bool empty() { return this->begin() == this->end(); }
};





IterateWrapper VehicleOrders (const Vehicle *vehicle);





#endif /* ORDER_ITERATOR_H */
